---
title: 허브형 간편결제 서비스 및 수수료 소개
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
seo:
  title: 허브형 간편결제 서비스 설명
  description: >-
    간편결제사(카카오페이, 네이버페이, 페이코 등)와 직접 계약을 맺지 않고 기본PG사(KG이니시스, KCP, 토스페이먼츠 등)계약만으로
    서비스 이용이 가능한 간편결제입니다.
  keywords:
    - 간편결제
tags:
  - 공통
  - 간편결제
pgCompanies:
  - 웰컴페이먼츠
  - KSNET
  - 스마트로
  - 나이스페이먼츠
  - KG이니시스
  - NHN KCP
  - 토스페이먼츠
searchTags:
  - 토스페이먼츠 간편결제
  - KCP 간편결제
  - KG이니시스 간편결제
  - 간편결제추가
  - 페이코
  - 네이버페이 허브형
  - 카카오페이 허브형
  - 간편결제 수수료
  - 간편결제
  - 허브형
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="허브형 간편결제의 개념을 소개하고 서비스 이용시 참고하실 정보를 안내드립니다." />

### **허브형 간편결제란?**

간편결제사(카카오페이, 네이버페이, 페이코 등)와 직접 계약을 맺지 않고 기본 결제대행사(KG이니시스, NHN KCP, 토스페이먼츠 등)의 계약만으로 서비스 이용이 가능한 결제

- 기본 결제대행사(PG)사란, 카드/계좌이체/가상계좌/휴대폰 결제 등의 일반 결제수단을 제공하는 결제대행사(PG)입니다.

### **허브형 간편결제를 이용하는 이유**

- 기본 결제대행사와 이미 계약이 되어있으신 경우 추가적인 계약 없이 이용하고 있던 기존 결제대행사를 통한 신청만으로 서비스 이용이 가능합니다.
- 계약, 정산 등의 결제 관리를 한 결제대행사를 통해서 진행하실 수 있습니다.

### **간편결제 지원하는 결제대행사 목록**

- KG이니시스 : 카카오페이, 네이버페이, 페이코, 토스페이, 삼성페이, 애플페이, SSGpay, Lpay
- NHN KCP : 카카오페이, 네이버페이, 페이코, 삼성페이, 애플페이, SSGpay, Lpay
- 나이스페이먼츠 :
  - 구모듈 : 카카오페이, 네이버페이
  - 신모듈 : 카카오페이, 네이버페이, 페이코, 삼성페이, 애플페이, SSGpay, Lpay, SK페이
- 토스페이먼츠 (구모듈/신모듈) : 카카오페이, 네이버페이, 토스페이, 페이코, 삼성페이, 애플페이, SSGpay, Lpay
- 스마트로 (신모듈) : 카카오페이, 네이버페이, 페이코, Lpay, pinpay
- KSNET : 카카오페이, 네이버페이, 페이코, SSGpay, Lpay
- 웰컴페이먼츠 : 카카오페이, 페이코, Lpay, 토스페이
- 한국결제네트웍스(KPN) : 카카오페이, 네이버페이, 페이코, 토스페이, 삼성페이

### **허브형 간편결제 수수료율 표 (vat별도)**

- 서비스 미지원일 경우 공란으로 표기
- 일부 허브형 간편결제 수수료율은 일반 수수료율을 기준으로 + n %로 적용됩니다. 운영하시는 고객사의 사업자 구분(영세/중소/일반)에 따른 카드 수수료율을 기준으로 계산하여 참고해주시기 바랍니다.
  - 간편결제 카드 : 기본 PG사를 통해 이용중인 카드의 영중소 구간별 수수료율과 동일하게 적용됩니다. \
    (ex. KG이니시스 카드 중소1 구간 기준 2.30%)
  - 간편결제 머니/포인트 : 기본 PG사를 통해 이용중인 카드의 일반사업자 기준 수수료율과 동일하게 적용됩니다. (ex. KG이니시스 카드 일반사업자 기준 3.20%)
  - 삼성페이는 삼성페이 정책상, 카드 수수료의 0.30%가 추가 발생됩니다. \
    (ex. KG이니시스 카드 중소1 구간 기준 2.33%)

<Callout content="- 네이버페이 : 포인트 적립불가
- 카카오페이 : 지원 결제수단 '카드/머니'
- 페이코 : 지원 결제수단 '카드/포인트'
- SSG페이 : 지원 결제수단 '카드/머니'
- 나이스페이먼츠(구모듈) : 네이버페이는 결제창 안에서 선택가능 (직접 호출 불가)
- KSNET : 결제창 안에서 선택가능 (직접 호출 불가) " title="참고사항" icon="💡" />

